@@ -17,9 +17,10 @@ module.exports = {
     GenerateLib: 15,
     InvokeGlobalMethod: 16,
     DestructReference: 17,
-    Array: 18,
+    ArrayReference: 18,
     ArrayGetItem: 19,
     ArrayGetSize: 20,
     ArrayGetRank: 21,
-    ArraySetItem: 22
+    ArraySetItem: 22,
+    Array: 23
 }
\ No newline at end of file
